==> ircd-ratbox-1.0.tgz: ircd-ratbox-1.0/include/resv.h <==
/*
 *  ircd-ratbox: an advanced Internet Relay Chat Daemon(ircd).
 *  restart.h: A header for the restart functions.
 *
 *  Copyright (C) 1990 Jarkko Oikarinen and University of Oulu, Co Center
 *  Copyright (C) 1996-2002 Hybrid Development Team
 *  Copyright (C) 2002 ircd-ratbox development team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: resv.h,v 1.13 2002/11/21 21:18:22 leeh Exp $
 */

#ifndef INCLUDED_resv_h
#define INCLUDED_resv_h

#define RESV_CHANNEL    0x0001
#define RESV_NICK       0x0002
#define RESV_NICKWILD   0x0004

struct ResvEntry
{
  char *name;
  char *reason;
  int flags;
};

extern dlink_list resv_channel_list;
extern dlink_list resv_nick_list;

extern struct ResvEntry *create_resv(char *, char *, int);

extern int delete_resv(struct ResvEntry *);
extern void clear_resv(void);

extern int find_channel_resv(char *);
extern int find_nick_resv(char *);
extern struct ResvEntry *get_nick_resv(char *);

extern void report_resv(struct Client *);

extern int clean_resv_nick(char *);

#endif  /* INCLUDED_hash_h */

==> ircd-ratbox-1.1.tgz: ircd-ratbox-1.1/include/resv.h <==
/*
 *  ircd-ratbox: an advanced Internet Relay Chat Daemon(ircd).
 *  restart.h: A header for the restart functions.
 *
 *  Copyright (C) 1990 Jarkko Oikarinen and University of Oulu, Co Center
 *  Copyright (C) 1996-2002 Hybrid Development Team
 *  Copyright (C) 2002 ircd-ratbox development team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: resv.h,v 1.16 2003/02/24 20:21:00 leeh Exp $
 */

#ifndef INCLUDED_resv_h
#define INCLUDED_resv_h

#define RESV_CHANNEL    0x0001
#define RESV_NICK       0x0002
#define RESV_NICKWILD   0x0004

struct ResvEntry
{
	char *name;
	char *reason;
	int flags;
};

extern dlink_list resv_channel_list;
extern dlink_list resv_nick_list;

extern struct ResvEntry *create_resv(char *, char *, int);

extern int delete_resv(struct ResvEntry *);
extern void clear_resv(void);

extern int find_channel_resv(const char *);
extern int find_nick_resv(char *);
extern struct ResvEntry *get_nick_resv(char *);

extern void report_resv(struct Client *);

extern int clean_resv_nick(char *);
extern int valid_wild_card_simple(const char *);
#endif /* INCLUDED_hash_h */
